from .saucenao_api import SauceNao
from .containers import BasicSauce, BookSauce, VideoSauce


__author__ = 'nomnoms12'
__copyright__ = 'Copyright 2020, Taiga.sh Development'
__credits__ = ['nomnoms12', 'FujiMakoto']
__license__ = 'GNU General Public License v3.0'
__version__ = '1.0.2'
__maintainer__ = 'nomnoms12'
__email__ = 'alexander.ign0918@gmail.com'
__status__ = 'Production'
